package test;

/**
 * Class that allows a suite of deterministic and stochastic algorithms
 * to run the simulation.
 * @author R J Crossland
 */
public class Algorithms {

    /**
     * The Euler algorithm is a deterministic one. Here it simulates
     * the dynamics of a simple two-gene repression system. Protein (P1)
     * encoded by G1 the linear DNA repressors a second protein (P2) encoded
     * by G2. G2 is located either on the bacterial chromosome or a
     * circular plasmid. As a result of linear DNA shortening, the
     * transcription of G1 is turned off after a time delay.
     */
    public void oneRepressorEuler(double dt, Cell cell, int i) {

        double[] k = cell.allK[i - 1]; // rates
        double[] x = cell.allX[i - 1]; // quantities

        // calculate change in quantities
        double[] dx = new double[x.length];
        dx[0] = (k[2] * x[4] - k[0] * x[0] * x[1] + k[1] *
                x[3] - k[4] * x[0]);                 // P1
        dx[1] = (k[1] * x[3] - k[0] * x[0] * x[1]);  //G2
        dx[2] = (k[3] * x[1] - k[5] * x[2]);         //P2
        dx[3] = (k[0] * x[0] * x[1] - k[1] * x[3]);  // P1.G2
        dx[4] = 0;                                   // G1 no change in G1

        // update quantities
        for (int xCol = 0; xCol < dx.length; xCol++) {
            cell.allX[i][xCol] = cell.allX[i - 1][xCol] + dx[xCol] * dt;
        }
    }
}
// ... other algorithms, e.g. oneRepressorGillespie()



