package test;

/**
 * Class representing a cell as a compartment for a linear DNA molecule.
 * The cell object is also a data structure for the rates of intra-cellular
 * reactions (in minutes) and the quantities of the reacting species.
 * @author R J Crossland
 */
public class Cell {

    double[][] allK;
    double[][] allX;
    LinearDNA dna1;

    /**
     * Constructor for a cell.
     * @param k  rates of chemical reactions.
     * @param x  quantities of reacting species.
     * @param dna1  linear DNA molecule within the cell.
     * @param n  total number of time points in simulation.
     */
    public Cell(double[] k, double[] x, LinearDNA dna1, double n) {

        allK = new double[(int) n][k.length];
        allX = new double[(int) n][x.length];
        this.dna1 = dna1;

        this.allX[0] = x;
        this.allK[0] = k;

        for (int i = 1; i < n; i++) { // fill with default values

            for (int kCol = 0; kCol < k.length; kCol++) {
                this.allK[i][kCol] = k[kCol];
            }
            for (int xCol = 0; xCol < x.length; xCol++) {
                this.allX[i][xCol] = 0;
            }
        }
    }
}
