package test;

/**
 * Class representing a linear DNA molecule and the things that can happen
 * to it. A linear DNA molecule has a length and can contain a number of
 * structures (genes, telomeres, ER2s etc). Exposed ends of linear DNAs
 * are subject to exonuclease attack which shortenen the molecule.
 * @author R J Crossland
 */
public class LinearDNA {

    Structure[] allStr;
    double[] lengths;

    /**
     * Constructor for a linear DNA.
     * @param length  length of linear DNA molecule at time = 0.
     * @param n  total number of time points in simulation.
     * @param structures  all structures on the linear DNA.
     */
    public LinearDNA(double length, double n, Structure... allStr) {

        this.allStr = allStr;
        lengths = new double[(int) n];
        this.lengths[0] = length;
    }

    /**
     * The shortening of linear DNA exposed ends by exonuclease enzymes.
     * @param dt  incremental time interval.
     * @param i  current time point in simulation.
     * @param attackRate  rate of exonuclease enzyme shortening.
     * @param cell  cellular compartment in which reactions occur.
     */
    public void exonucleaseAttack(double dt, double i, double attackRate, Cell cell) {

        if ((this.lengths[(int) i - 1] - attackRate * dt) < 0) {
            this.lengths[(int) i] = 0;

        } else {
            this.lengths[(int) i] = this.lengths[(int) i - 1] - attackRate * dt;
        }
    }
}
