package test;

/**
 *
 * @author R J Crossland
 */
public class Test {

    static double dt = 0.01;
    static int time = 200;
    static double n = time / dt; // number of time points
    // effects of disrupting structure G1
    static double[][] g1OffK = {{2, 0.0}}; // reaction index, new rate
    static int g1OffX = 4; // set gene 1 quantity to zero
    // array of intial quantities (x)
    static double[] x = new double[]{
        0, //  P1
        0, // G2
        0, // P2
        1, //  P1.G2
        1}; // G1
    // arrray of initial rate constants (k)
    static double[] k = new double[]{
        1.0, //  repression forming
        0.01, //  repression separating
        0.5, //  P1 protein synthesis
        0.9, //  P2 protein synthesis
        0.5, //  P1 degradation
        0.5};  //  P2 degradation

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        Test test = new Test();
        test.run(x, k); // quantities, rates
    }

    public void run(double[] x, double[] k) {

        // create stuctures, linear DNAs and cells
        Structure G1 = new Structure("G1", 18, 19, true, n, g1OffK, g1OffX);
        LinearDNA dna1 = new LinearDNA(33, n, G1);
        Cell cell = new Cell(k, x, dna1, n);

        Algorithms algorithms = new Algorithms();

        // loop over algorithm, exonuclease attack
        for (int i = 1; i < n; i++) {
            algorithms.oneRepressorEuler(dt, cell, i);
            dna1.exonucleaseAttack(dt, i, 0.8, cell);

            // test whether a structure has been disrupted
            for (int allStrInd = 0; allStrInd < dna1.allStr.length; allStrInd++) {
                dna1.allStr[allStrInd].disruptStructure(cell, i, dna1);
            }
        }

        // print results to starndard output
        this.outputOption(dna1, cell);
    }

    public void outputOption(LinearDNA dna1, Cell cell) {

        System.out.printf("%-8s%-25s%-25s%-25s%-25s%-25s%-25s%n", "Time", "P1", "G2", "P2", "P1.G2", "G1", "DNA.length");

        for (int i = 0; i < n; i++) {
            System.out.printf("%-8.5s", i * dt); // time
            // print quantities
            for (int allXCol = 0; allXCol < cell.allX[0].length; allXCol++) {

                System.out.printf("%-25s", cell.allX[i][allXCol]);
            }

            // print linear DNA length
            System.out.printf("%-25s", dna1.lengths[i]);

            // print structure info
            for (int allStrInd = 0; allStrInd < dna1.allStr.length; allStrInd++) { // for each structure
                Structure str = dna1.allStr[allStrInd];
                System.out.printf("%-3s%-6.4s%-6.4s%-7s", str.names[i], str.startBps[i], str.endBps[i], str.onOrOffs[i]);
            }

            // print rates
            for (int allKInd = 0; allKInd < cell.allK[0].length; allKInd++) {
                System.out.printf("%-8.5s", cell.allK[i][allKInd]);
            }
            System.out.println();
        }
    }
}